Class: Calendly::Client

Inherits:
Object
  • Object
show all
Includes:
Loggable
Defined in:
lib/calendly/client.rb

Overview

Calendly apis client.

Constant Summary collapse

API_HOST =
'https://api.calendly.com'
AUTH_API_HOST =
'https://auth.calendly.com'

Instance Method Summary collapse

Methods included from Loggable

#debug_log, #error_log, #info_log, #warn_log

Constructor Details

#initialize(token = nil) ⇒ Client

Returns a new instance of Client.

Raises:



15
16
17
18
19
20
21
# File 'lib/calendly/client.rb', line 15

def initialize(token = nil)
  @config = Calendly.configuration
  @token = token || Calendly.configuration.token

  check_not_empty @token, 'token'
  check_token
end

Instance Method Details

#access_tokenOAuth2::AccessToken

Get access token object.

Since:

  • 0.0.1



28
29
30
31
32
33
34
35
36
37
38
# File 'lib/calendly/client.rb', line 28

def access_token
  return @access_token if defined?(@access_token) && @access_token

  client = OAuth2::Client.new(@config.client_id,
                              @config.client_secret, client_options)
  @access_token = OAuth2::AccessToken.new(
    client, @token,
    refresh_token: @config.refresh_token,
    expires_at: @config.token_expires_at
  )
end

#create_invitation(uuid, email) ⇒ Calendly::OrganizationInvitation

Invite a person to an Organization.

Raises:

Since:

  • 0.0.7



491
492
493
494
495
496
497
498
499
500
# File 'lib/calendly/client.rb', line 491

def create_invitation(uuid, email)
  check_not_empty uuid, 'uuid'
  check_not_empty email, 'email'
  body = request(
    :post,
    "organizations/#{uuid}/invitations",
    body: {email: email}
  )
  OrganizationInvitation.new body[:resource], self
end

#create_invitee_no_show(invitee_uri) ⇒ Calendly::InviteeNoShow

Create Invitee No Show Marks an Invitee as a No Show.

Raises:

Since:

  • 0.9.0



309
310
311
312
313
314
315
316
317
# File 'lib/calendly/client.rb', line 309

def create_invitee_no_show(invitee_uri)
  check_not_empty invitee_uri, 'invitee_uri'
  body = request(
    :post,
    'invitee_no_shows',
    body: {invitee: invitee_uri}
  )
  InviteeNoShow.new body[:resource], self
end

Create a scheduling link.

e.g.

booking_url: "https://calendly.com/s/FOO-BAR-SLUG",
owner: "https://api.calendly.com/event_types/GBGBDCAADAEDCRZ2",
owner_type: "EventType"

Raises:

Since:

  • 0.5.2



652
653
654
655
656
657
658
659
660
661
662
663
# File 'lib/calendly/client.rb', line 652

def create_schedule_link(uri, max_event_count: 1, owner_type: 'EventType')
  check_not_empty uri, 'uri'
  check_not_empty max_event_count, 'max_event_count'
  check_not_empty owner_type, 'owner_type'
  params = {
    max_event_count: max_event_count,
    owner: uri,
    owner_type: owner_type
  }
  body = request :post, 'scheduling_links', body: params
  body[:resource]
end

#create_webhook(url, events, org_uri, user_uri: nil, signing_key: nil) ⇒ Calendly::WebhookSubscription

Create a webhook subscription for an organization or user.

Raises:

Since:

  • 0.1.3



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/calendly/client.rb', line 602

def create_webhook(url, events, org_uri, user_uri: nil, signing_key: nil) # rubocop:disable Metrics/ParameterLists
  check_not_empty url, 'url'
  check_not_empty events, 'events'
  check_not_empty org_uri, 'org_uri'

  params = {url: url, events: events, organization: org_uri}
  params[:signing_key] = signing_key if signing_key

  if user_uri
    params[:scope] = 'user'
    params[:user] = user_uri
  else
    params[:scope] = 'organization'
  end
  body = request :post, 'webhook_subscriptions', body: params
  WebhookSubscription.new body[:resource], self
end

#current_userCalendly::User Also known as: me

Get basic information about current user.

Raises:

Since:

  • 0.0.1



62
63
64
65
66
# File 'lib/calendly/client.rb', line 62

def current_user
  return @cached_current_user if defined?(@cached_current_user) && @cached_current_user

  @cached_current_user = user
end

#current_user!Object Also known as: me!

Since:

  • 0.2.0



71
72
73
74
# File 'lib/calendly/client.rb', line 71

def current_user!
  @cached_current_user = nil
  current_user
end

#delete_invitation(org_uuid, inv_uuid) ⇒ true

Revoke Organization Invitation.

Raises:

Since:

  • 0.0.7



512
513
514
515
516
517
# File 'lib/calendly/client.rb', line 512

def delete_invitation(org_uuid, inv_uuid)
  check_not_empty org_uuid, 'org_uuid'
  check_not_empty inv_uuid, 'inv_uuid'
  request :delete, "organizations/#{org_uuid}/invitations/#{inv_uuid}"
  true
end

#delete_invitee_data(emails) ⇒ true

Delete Invitee Data To submit a request to remove invitee data from all previously booked events in your organization.

Raises:

Since:

  • 0.10.0



343
344
345
346
347
348
349
350
351
# File 'lib/calendly/client.rb', line 343

def delete_invitee_data(emails)
  check_not_empty emails, 'emails'
  request(
    :post,
    'data_compliance/deletion/invitees',
    body: {emails: emails}
  )
  true
end

#delete_invitee_no_show(uuid) ⇒ true

Delete Invitee No Show Undoes marking an Invitee as a No Show.

Raises:

Since:

  • 0.9.0



328
329
330
331
332
# File 'lib/calendly/client.rb', line 328

def delete_invitee_no_show(uuid)
  check_not_empty uuid, 'uuid'
  request :delete, "invitee_no_shows/#{uuid}"
  true
end

#delete_membership(uuid) ⇒ true

Remove a User from an Organization.

Raises:

Since:

  • 0.0.7



429
430
431
432
433
# File 'lib/calendly/client.rb', line 429

def delete_membership(uuid)
  check_not_empty uuid, 'uuid'
  request :delete, "organization_memberships/#{uuid}"
  true
end

#delete_webhook(uuid) ⇒ true

Delete a webhook subscription for an organization or user with a specified UUID.

Raises:

Since:

  • 0.1.3



628
629
630
631
632
# File 'lib/calendly/client.rb', line 628

def delete_webhook(uuid)
  check_not_empty uuid, 'uuid'
  request :delete, "webhook_subscriptions/#{uuid}"
  true
end

#event_invitee(ev_uuid, inv_uuid) ⇒ Calendly::Invitee

Get Invitee of an Event Returns a single Invitee by their URI.

Raises:

Since:

  • 0.0.4



250
251
252
253
254
255
# File 'lib/calendly/client.rb', line 250

def event_invitee(ev_uuid, inv_uuid)
  check_not_empty ev_uuid, 'ev_uuid'
  check_not_empty inv_uuid, 'inv_uuid'
  body = request :get, "scheduled_events/#{ev_uuid}/invitees/#{inv_uuid}"
  Invitee.new body[:resource], self
end

#event_invitees(uuid, options: nil) ⇒ Array<Array<Calendly::Invitee>, Hash>

Get List of Event Invitees.

Options Hash (options:):

  • :count (Integer)

    Number of rows to return.

  • :email (String)

    Filter by email.

  • :page_token (String)

    Pass this to get the next portion of collection.

  • :sort (String)

    Order results by the specified field and directin. Accepts comma-separated list of field:direction values.

  • :status (String)

    Whether the scheduled event is active or canceled.

Raises:

Since:

  • 0.0.4



273
274
275
276
277
278
279
280
281
282
283
# File 'lib/calendly/client.rb', line 273

def event_invitees(uuid, options: nil)
  check_not_empty uuid, 'uuid'

  opts_keys = i[count email page_token sort status]
  params = merge_options options, opts_keys
  body = request :get, "scheduled_events/#{uuid}/invitees", params: params

  items = body[:collection] || []
  evs = items.map { |item| Invitee.new item, self }
  [evs, next_page_params(body)]
end

#event_type(uuid) ⇒ Calendly::EventType

Returns a single Event Type by its UUID.

Raises:

Since:

  • 0.4.1



100
101
102
103
104
# File 'lib/calendly/client.rb', line 100

def event_type(uuid)
  check_not_empty uuid, 'uuid'
  body = request :get, "event_types/#{uuid}"
  EventType.new body[:resource], self
end

#event_types(org_uri, options: nil) ⇒ Array<Array<Calendly::EventType>, Hash>

Returns all Event Types associated with a specified organization.

Options Hash (options:):

  • :active (Boolean)

    Return only active event types if true, only inactive if false, or all event types if this parameter is omitted.

  • :count (Integer)

    Number of rows to return.

  • :page_token (String)

    Pass this to get the next portion of collection.

  • :sort (String)

    Order results by the specified field and direction. Accepts comma-separated list of field:direction values.

Raises:

Since:

  • 0.6.0



121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/calendly/client.rb', line 121

def event_types(org_uri, options: nil)
  check_not_empty org_uri, 'org_uri'

  opts_keys = i[active count page_token sort]
  params = {organization: org_uri}
  params = merge_options options, opts_keys, params
  body = request :get, 'event_types', params: params

  items = body[:collection] || []
  ev_types = items.map { |item| EventType.new item, self }
  [ev_types, next_page_params(body)]
end

#event_types_by_user(user_uri, options: nil) ⇒ Array<Array<Calendly::EventType>, Hash>

Returns all Event Types associated with a specified user.

Options Hash (options:):

  • :active (Boolean)

    Return only active event types if true, only inactive if false, or all event types if this parameter is omitted.

  • :count (Integer)

    Number of rows to return.

  • :page_token (String)

    Pass this to get the next portion of collection.

  • :sort (String)

    Order results by the specified field and direction. Accepts comma-separated list of field:direction values.

Raises:

Since:

  • 0.0.2



149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/calendly/client.rb', line 149

def event_types_by_user(user_uri, options: nil)
  check_not_empty user_uri, 'user_uri'

  opts_keys = i[active count page_token sort]
  params = {user: user_uri}
  params = merge_options options, opts_keys, params
  body = request :get, 'event_types', params: params

  items = body[:collection] || []
  ev_types = items.map { |item| EventType.new item, self }
  [ev_types, next_page_params(body)]
end

#invitation(org_uuid, inv_uuid) ⇒ Calendly::OrganizationInvitation

Returns an Organization Invitation.

Raises:

Since:

  • 0.0.6



445
446
447
448
449
450
451
# File 'lib/calendly/client.rb', line 445

def invitation(org_uuid, inv_uuid)
  check_not_empty org_uuid, 'org_uuid'
  check_not_empty inv_uuid, 'inv_uuid'

  body = request :get, "organizations/#{org_uuid}/invitations/#{inv_uuid}"
  OrganizationInvitation.new body[:resource], self
end

#invitations(uuid, options: nil) ⇒ <Array<Array<Calendly::OrganizationInvitation>, Hash>] - [Array<Calendly::OrganizationInvitation>] organizations - [Hash] next_params the parameters to get next data. if thre is no next it returns nil.

Get Organization Invitations.

Options Hash (options:):

  • :count (Integer)

    Number of rows to return.

  • :email (String)

    Filter by email.

  • :page_token (String)

    Pass this to get the next portion of collection.

  • :sort (String)

    Order results by the specified field and directin. Accepts comma-separated list of field:direction values.

  • :status (String)

    Filter by status.

Raises:

Since:

  • 0.0.6



469
470
471
472
473
474
475
476
477
478
479
# File 'lib/calendly/client.rb', line 469

def invitations(uuid, options: nil)
  check_not_empty uuid, 'uuid'

  opts_keys = i[count email page_token sort status]
  params = merge_options options, opts_keys

  body = request :get, "organizations/#{uuid}/invitations", params: params
  items = body[:collection] || []
  evs = items.map { |item| OrganizationInvitation.new item, self }
  [evs, next_page_params(body)]
end

#invitee_no_show(uuid) ⇒ Calendly::InviteeNoShow

Get Invitee No Show Returns information about a specified Invitee No Show.

Raises:

Since:

  • 0.9.0



294
295
296
297
298
# File 'lib/calendly/client.rb', line 294

def invitee_no_show(uuid)
  check_not_empty uuid, 'uuid'
  body = request :get, "invitee_no_shows/#{uuid}"
  InviteeNoShow.new body[:resource], self
end

#membership(uuid) ⇒ Calendly::OrganizationMembership

Returns information about a user’s organization membership

Raises:

Since:

  • 0.0.5



361
362
363
364
365
# File 'lib/calendly/client.rb', line 361

def membership(uuid)
  check_not_empty uuid, 'uuid'
  body = request :get, "organization_memberships/#{uuid}"
  OrganizationMembership.new body[:resource], self
end

#memberships(org_uri, options: nil) ⇒ Array<Array<Calendly::OrganizationMembership>, Hash>

Get List of memberships belonging to specific an organization.

Options Hash (options:):

  • :count (Integer)

    Number of rows to return.

  • :email (String)

    Filter by email.

  • :page_token (String)

    Pass this to get the next portion of collection.

Raises:

Since:

  • 0.0.5



381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/calendly/client.rb', line 381

def memberships(org_uri, options: nil)
  check_not_empty org_uri, 'org_uri'

  opts_keys = i[count email page_token]
  params = {organization: org_uri}
  params = merge_options options, opts_keys, params
  body = request :get, 'organization_memberships', params: params

  items = body[:collection] || []
  memberships = items.map { |item| OrganizationMembership.new item, self }
  [memberships, next_page_params(body)]
end

#memberships_by_user(user_uri, options: nil) ⇒ Array<Array<Calendly::OrganizationMembership>, Hash>

Get List of memberships belonging to specific a user.

Options Hash (options:):

  • :count (Integer)

    Number of rows to return.

  • :email (String)

    Filter by email.

  • :page_token (String)

    Pass this to get the next portion of collection.

Raises:

Since:

  • 0.0.5



408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/calendly/client.rb', line 408

def memberships_by_user(user_uri, options: nil)
  check_not_empty user_uri, 'user_uri'

  opts_keys = i[count email page_token]
  params = {user: user_uri}
  params = merge_options options, opts_keys, params
  body = request :get, 'organization_memberships', params: params

  items = body[:collection] || []
  memberships = items.map { |item| OrganizationMembership.new item, self }
  [memberships, next_page_params(body)]
end

#refresh!Object

Refresh access token.

Raises:

Since:

  • 0.0.7



47
48
49
50
51
52
53
54
# File 'lib/calendly/client.rb', line 47

def refresh!
  check_not_empty @config.client_id, 'client_id'
  check_not_empty @config.client_secret, 'client_secret'
  @access_token = access_token.refresh!
rescue OAuth2::Error => e
  res = e.response.response
  raise ApiError.new res, e
end

#scheduled_event(uuid) ⇒ Calendly::Event

Returns a single Event by its URI.

Raises:

Since:

  • 0.0.3



170
171
172
173
174
# File 'lib/calendly/client.rb', line 170

def scheduled_event(uuid)
  check_not_empty uuid, 'uuid'
  body = request :get, "scheduled_events/#{uuid}"
  Event.new body[:resource], self
end

#scheduled_events(org_uri, options: nil) ⇒ Array<Array<Calendly::Event>, Hash>

Get List of scheduled events belonging to a specific organization.

Options Hash (options:):

  • :count (Integer)

    Number of rows to return.

  • :invitee_email (String)

    Return events scheduled with the specified invitee email.

  • :max_start_time (String)

    Upper bound (inclusive) for an event’s start time to filter by.

  • :min_start_time (String)

    Lower bound (inclusive) for an event’s start time to filter by.

  • :page_token (String)

    Pass this to get the next portion of collection.

  • :sort (String)

    Order results by the specified field and directin. Accepts comma-separated list of field:direction values.

  • :status (String)

    Whether the scheduled event is active or canceled.

Raises:

Since:

  • 0.5.0



194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/calendly/client.rb', line 194

def scheduled_events(org_uri, options: nil)
  check_not_empty org_uri, 'org_uri'

  opts_keys = i[count invitee_email max_start_time min_start_time page_token sort status]
  params = {organization: org_uri}
  params = merge_options options, opts_keys, params
  body = request :get, 'scheduled_events', params: params

  items = body[:collection] || []
  evs = items.map { |item| Event.new item, self }
  [evs, next_page_params(body)]
end

#scheduled_events_by_user(user_uri, options: nil) ⇒ Array<Array<Calendly::Event>, Hash>

Get List of scheduled events belonging to a specific user.

Options Hash (options:):

  • :organization (String)

    the specified organization (organization’s uri).

  • :count (Integer)

    Number of rows to return.

  • :invitee_email (String)

    Return events scheduled with the specified invitee email.

  • :max_start_time (String)

    Upper bound (inclusive) for an event’s start time to filter by.

  • :min_start_time (String)

    Lower bound (inclusive) for an event’s start time to filter by.

  • :page_token (String)

    Pass this to get the next portion of collection.

  • :sort (String)

    Order results by the specified field and directin. Accepts comma-separated list of field:direction values.

  • :status (String)

    Whether the scheduled event is active or canceled.

Raises:

Since:

  • 0.0.3



226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/calendly/client.rb', line 226

def scheduled_events_by_user(user_uri, options: nil)
  check_not_empty user_uri, 'user_uri'

  opts_keys = i[organization count invitee_email max_start_time min_start_time page_token sort status]
  params = {user: user_uri}
  params = merge_options options, opts_keys, params
  body = request :get, 'scheduled_events', params: params

  items = body[:collection] || []
  evs = items.map { |item| Event.new item, self }
  [evs, next_page_params(body)]
end

#user(uuid = 'me') ⇒ Calendly::User

Get basic information about a user

Raises:

Since:

  • 0.0.1



86
87
88
89
90
# File 'lib/calendly/client.rb', line 86

def user(uuid = 'me')
  check_not_empty uuid, 'uuid'
  body = request :get, "users/#{uuid}"
  User.new body[:resource], self
end

#user_scope_webhooks(org_uri, user_uri, options: nil) ⇒ Array<Array<Calendly::WebhookSubscription>, Hash>

Get List of user scope Webhooks.

Options Hash (options:):

  • :count (Integer)

    Number of rows to return.

  • :page_token (String)

    Pass this to get the next portion of collection.

  • :sort (String)

    Order results by the specified field and directin. Accepts comma-separated list of field:direction values.

Raises:

Since:

  • 0.1.3



575
576
577
578
579
580
581
582
583
584
585
586
# File 'lib/calendly/client.rb', line 575

def user_scope_webhooks(org_uri, user_uri, options: nil)
  check_not_empty org_uri, 'org_uri'
  check_not_empty user_uri, 'user_uri'

  opts_keys = i[count page_token sort]
  params = {organization: org_uri, user: user_uri, scope: 'user'}
  params = merge_options options, opts_keys, params
  body = request :get, 'webhook_subscriptions', params: params
  items = body[:collection] || []
  evs = items.map { |item| WebhookSubscription.new item, self }
  [evs, next_page_params(body)]
end

#webhook(uuid) ⇒ Calendly::WebhookSubscription

Get a webhook subscription for an organization or user with a specified UUID.

Raises:

Since:

  • 0.1.3



527
528
529
530
531
# File 'lib/calendly/client.rb', line 527

def webhook(uuid)
  check_not_empty uuid, 'uuid'
  body = request :get, "webhook_subscriptions/#{uuid}"
  WebhookSubscription.new body[:resource], self
end

#webhooks(org_uri, options: nil) ⇒ Array<Array<Calendly::WebhookSubscription>, Hash>

Get List of organization scope Webhooks.

Options Hash (options:):

  • :count (Integer)

    Number of rows to return.

  • :page_token (String)

    Pass this to get the next portion of collection.

  • :sort (String)

    Order results by the specified field and directin. Accepts comma-separated list of field:direction values.

Raises:

Since:

  • 0.1.3



547
548
549
550
551
552
553
554
555
556
557
# File 'lib/calendly/client.rb', line 547

def webhooks(org_uri, options: nil)
  check_not_empty org_uri, 'org_uri'

  opts_keys = i[count page_token sort]
  params = {organization: org_uri, scope: 'organization'}
  params = merge_options options, opts_keys, params
  body = request :get, 'webhook_subscriptions', params: params
  items = body[:collection] || []
  evs = items.map { |item| WebhookSubscription.new item, self }
  [evs, next_page_params(body)]
end