Class: Calendly::EventTypeProfile

Inherits:
Object
  • Object
show all
Includes:
ModelUtils
Defined in:
lib/calendly/models/event_type_profile.rb

Overview

Calendly’s event type profile model.

Constant Summary

Constants included from ModelUtils

ModelUtils::UUID_FORMAT

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from ModelUtils

#client, #id, included, #initialize, #inspect

Instance Attribute Details

#nameString

Human-readable name for the profile of the user that’s associated with the event type

Returns:

  • (String)


16
17
18
# File 'lib/calendly/models/event_type_profile.rb', line 16

def name
  @name
end

#ownerString

The unique reference to the user associated with the profile

Returns:

  • (String)


20
21
22
# File 'lib/calendly/models/event_type_profile.rb', line 20

def owner
  @owner
end

#owner_teamTeam

The owner team if the profile belongs to a “team”.

Returns:



28
29
30
# File 'lib/calendly/models/event_type_profile.rb', line 28

def owner_team
  @owner_team
end

#owner_userUser

The owner user if the profile belongs to a “user” (individual).

Returns:



24
25
26
# File 'lib/calendly/models/event_type_profile.rb', line 24

def owner_user
  @owner_user
end

#typeString

Indicates if the profile belongs to a “user” (individual) or “team”

Returns:

  • (String)


12
13
14
# File 'lib/calendly/models/event_type_profile.rb', line 12

def type
  @type
end

Instance Method Details

#type_team?Boolean

whether type is team or not.

Returns:

  • (Boolean)

Since:

  • 0.6.0



40
41
42
# File 'lib/calendly/models/event_type_profile.rb', line 40

def type_team?
  type&.downcase == 'team'
end

#type_user?Boolean

whether type is user or not.

Returns:

  • (Boolean)

Since:

  • 0.6.0



33
34
35
# File 'lib/calendly/models/event_type_profile.rb', line 33

def type_user?
  type&.downcase == 'user'
end