Class: Calendly::Invitee

Inherits:
Object
  • Object
show all
Includes:
ModelUtils
Defined in:
lib/calendly/models/invitee.rb

Overview

Calendly’s invitee model. An individual who has been invited to meet with a Calendly member.

Constant Summary collapse

UUID_RE =
%r{\A#{Client::API_HOST}/scheduled_events/#{UUID_FORMAT}/invitees/(#{UUID_FORMAT})\z}.freeze
TIME_FIELDS =
i[created_at updated_at].freeze
ASSOCIATION =
{
  event: Event,
  cancellation: InviteeCancellation,
  payment: InviteePayment,
  questions_and_answers: InviteeQuestionAndAnswer,
  tracking: InviteeTracking
}.freeze

Constants included from ModelUtils

ModelUtils::UUID_FORMAT

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from ModelUtils

#client, #id, included, #initialize, #inspect

Instance Attribute Details

#cancel_urlString

Link to cancelling the event for the invitee.

Returns:

  • (String)


79
80
81
# File 'lib/calendly/models/invitee.rb', line 79

def cancel_url
  @cancel_url
end

#cancellationInviteeCancellation

Returns Provides data pertaining to the cancellation of the Invitee.

Returns:



94
95
96
# File 'lib/calendly/models/invitee.rb', line 94

def cancellation
  @cancellation
end

#created_atTime

Moment when user record was first created.

Returns:

  • (Time)


87
88
89
# File 'lib/calendly/models/invitee.rb', line 87

def created_at
  @created_at
end

#emailString

The invitee’s email address.

Returns:

  • (String)


36
37
38
# File 'lib/calendly/models/invitee.rb', line 36

def email
  @email
end

#eventEvent

Reference to Event associated with this invitee.

Returns:



101
102
103
# File 'lib/calendly/models/invitee.rb', line 101

def event
  @event
end

#first_nameString

The first name of the invitee who booked the event when the event type is configured to use separate fields for first name and last name. Null when event type is configured to use a single field for name.

Returns:

  • (String)


45
46
47
# File 'lib/calendly/models/invitee.rb', line 45

def first_name
  @first_name
end

#last_nameString

The last name of the invitee who booked the event when the event type is configured to use separate fields for first name and last name. Null when event type is configured to use a single field for name.

Returns:

  • (String)


50
51
52
# File 'lib/calendly/models/invitee.rb', line 50

def last_name
  @last_name
end

#nameString

The invitee’s human-readable name.

Returns:

  • (String)


40
41
42
# File 'lib/calendly/models/invitee.rb', line 40

def name
  @name
end

#new_inviteeString?

Link to new invitee, after reschedule.

Returns:

  • (String, nil)


75
76
77
# File 'lib/calendly/models/invitee.rb', line 75

def new_invitee
  @new_invitee
end

#old_inviteeString?

Reference to old Invitee instance that got rescheduled.

Returns:

  • (String, nil)


71
72
73
# File 'lib/calendly/models/invitee.rb', line 71

def old_invitee
  @old_invitee
end

#paymentInviteePayment

Returns Invitee payment.

Returns:



97
98
99
# File 'lib/calendly/models/invitee.rb', line 97

def payment
  @payment
end

#questions_and_answersArray<Calendly::InviteeQuestionAndAnswer>

A collection of form responses from the invitee.



105
106
107
# File 'lib/calendly/models/invitee.rb', line 105

def questions_and_answers
  @questions_and_answers
end

#reschedule_urlString

Link to rescheduling the event for the invitee.

Returns:

  • (String)


83
84
85
# File 'lib/calendly/models/invitee.rb', line 83

def reschedule_url
  @reschedule_url
end

#rescheduledBoolean

Indicates if this invitee has rescheduled. If true, a reference to the new Invitee instance is provided in the new_invitee field.

Returns:

  • (Boolean)


67
68
69
# File 'lib/calendly/models/invitee.rb', line 67

def rescheduled
  @rescheduled
end

#statusString

Whether the invitee has canceled or is still active.

Returns:

  • (String)


54
55
56
# File 'lib/calendly/models/invitee.rb', line 54

def status
  @status
end

#text_reminder_numberString

Text (SMS) reminder phone number.

Returns:

  • (String)


62
63
64
# File 'lib/calendly/models/invitee.rb', line 62

def text_reminder_number
  @text_reminder_number
end

#timezoneString

Timezone offest to use when presenting time information to invitee.

Returns:

  • (String)


58
59
60
# File 'lib/calendly/models/invitee.rb', line 58

def timezone
  @timezone
end

#trackingCalendly::InviteeTracking



108
109
110
# File 'lib/calendly/models/invitee.rb', line 108

def tracking
  @tracking
end

#updated_atTime

Moment when user record was last updated.

Returns:

  • (Time)


91
92
93
# File 'lib/calendly/models/invitee.rb', line 91

def updated_at
  @updated_at
end

#uriString

Canonical resource reference.

Returns:

  • (String)


32
33
34
# File 'lib/calendly/models/invitee.rb', line 32

def uri
  @uri
end

#uuidString

unique id of the Invitee object.

Returns:

  • (String)


28
29
30
# File 'lib/calendly/models/invitee.rb', line 28

def uuid
  @uuid
end

Instance Method Details

#fetchCalendly::Invitee

Get Event Invitee associated with self.

Returns:

Raises:

Since:

  • 0.1.0



118
119
120
121
# File 'lib/calendly/models/invitee.rb', line 118

def fetch
  ev_uuid = event.uuid if event
  client.event_invitee ev_uuid, uuid
end