Class: Calendly::InviteeQuestionAndAnswer
- Inherits:
-
Object
- Object
- Calendly::InviteeQuestionAndAnswer
- Includes:
- ModelUtils
- Defined in:
- lib/calendly/models/invitee_question_and_answer.rb
Overview
Calendly’s question and answer model. An individual form question and response.
Constant Summary
Constants included from ModelUtils
Instance Attribute Summary collapse
-
#answer ⇒ String
The answer supplied by the invitee to this question.
-
#position ⇒ Integer
The position of this question in the event booking confirmation form.
-
#question ⇒ String
The question from the event booking confirmation form.
Method Summary
Methods included from ModelUtils
#client, #id, included, #initialize, #inspect
Instance Attribute Details
#answer ⇒ String
The answer supplied by the invitee to this question.
17 18 19 |
# File 'lib/calendly/models/invitee_question_and_answer.rb', line 17 def answer @answer end |
#position ⇒ Integer
The position of this question in the event booking confirmation form.
21 22 23 |
# File 'lib/calendly/models/invitee_question_and_answer.rb', line 21 def position @position end |
#question ⇒ String
The question from the event booking confirmation form.
13 14 15 |
# File 'lib/calendly/models/invitee_question_and_answer.rb', line 13 def question @question end |