Class: Calendly::EventTypeProfile
- Inherits:
-
Object
- Object
- Calendly::EventTypeProfile
- Includes:
- ModelUtils
- Defined in:
- lib/calendly/models/event_type_profile.rb
Overview
Calendly’s event type profile model.
Constant Summary
Constants included from ModelUtils
Instance Attribute Summary collapse
-
#name ⇒ String
Human-readable name for the profile of the user that’s associated with the event type.
-
#owner ⇒ String
The unique reference to the user associated with the profile.
-
#owner_team ⇒ Team
The owner team if the profile belongs to a “team”.
-
#owner_user ⇒ User
The owner user if the profile belongs to a “user” (individual).
-
#type ⇒ String
Indicates if the profile belongs to a “user” (individual) or “team”.
Instance Method Summary collapse
-
#type_team? ⇒ Boolean
whether type is team or not.
-
#type_user? ⇒ Boolean
whether type is user or not.
Methods included from ModelUtils
#client, #id, included, #initialize, #inspect
Instance Attribute Details
#name ⇒ String
Human-readable name for the profile of the user that’s associated with the event type
16 17 18 |
# File 'lib/calendly/models/event_type_profile.rb', line 16 def name @name end |
#owner ⇒ String
The unique reference to the user associated with the profile
20 21 22 |
# File 'lib/calendly/models/event_type_profile.rb', line 20 def owner @owner end |
#owner_team ⇒ Team
The owner team if the profile belongs to a “team”.
28 29 30 |
# File 'lib/calendly/models/event_type_profile.rb', line 28 def owner_team @owner_team end |
#owner_user ⇒ User
The owner user if the profile belongs to a “user” (individual).
24 25 26 |
# File 'lib/calendly/models/event_type_profile.rb', line 24 def owner_user @owner_user end |
#type ⇒ String
Indicates if the profile belongs to a “user” (individual) or “team”
12 13 14 |
# File 'lib/calendly/models/event_type_profile.rb', line 12 def type @type end |
Instance Method Details
#type_team? ⇒ Boolean
whether type is team or not.
40 41 42 |
# File 'lib/calendly/models/event_type_profile.rb', line 40 def type_team? type&.downcase == 'team' end |
#type_user? ⇒ Boolean
whether type is user or not.
33 34 35 |
# File 'lib/calendly/models/event_type_profile.rb', line 33 def type_user? type&.downcase == 'user' end |