Class: Calendly::Invitee
- Inherits:
-
Object
- Object
- Calendly::Invitee
- Includes:
- ModelUtils
- Defined in:
- lib/calendly/models/invitee.rb
Overview
Calendly’s invitee model. An individual who has been invited to meet with a Calendly member.
Constant Summary collapse
- UUID_RE =
%r{\A#{Client::API_HOST}/scheduled_events/#{UUID_FORMAT}/invitees/(#{UUID_FORMAT})\z}.freeze
- TIME_FIELDS =
i[created_at updated_at].freeze
- ASSOCIATION =
{ event: Event, cancellation: InviteeCancellation, payment: InviteePayment, questions_and_answers: InviteeQuestionAndAnswer, tracking: InviteeTracking }.freeze
Constants included from ModelUtils
Instance Attribute Summary collapse
-
#cancel_url ⇒ String
Link to cancelling the event for the invitee.
-
#cancellation ⇒ InviteeCancellation
Provides data pertaining to the cancellation of the Invitee.
-
#created_at ⇒ Time
Moment when user record was first created.
-
#email ⇒ String
The invitee’s email address.
-
#event ⇒ Event
Reference to Event associated with this invitee.
-
#first_name ⇒ String
The first name of the invitee who booked the event when the event type is configured to use separate fields for first name and last name.
-
#last_name ⇒ String
The last name of the invitee who booked the event when the event type is configured to use separate fields for first name and last name.
-
#name ⇒ String
The invitee’s human-readable name.
-
#new_invitee ⇒ String?
Link to new invitee, after reschedule.
-
#old_invitee ⇒ String?
Reference to old Invitee instance that got rescheduled.
-
#payment ⇒ InviteePayment
Invitee payment.
-
#questions_and_answers ⇒ Array<Calendly::InviteeQuestionAndAnswer>
A collection of form responses from the invitee.
-
#reschedule_url ⇒ String
Link to rescheduling the event for the invitee.
-
#rescheduled ⇒ Boolean
Indicates if this invitee has rescheduled.
-
#status ⇒ String
Whether the invitee has canceled or is still active.
-
#text_reminder_number ⇒ String
Text (SMS) reminder phone number.
-
#timezone ⇒ String
Timezone offest to use when presenting time information to invitee.
- #tracking ⇒ Calendly::InviteeTracking
-
#updated_at ⇒ Time
Moment when user record was last updated.
-
#uri ⇒ String
Canonical resource reference.
-
#uuid ⇒ String
unique id of the Invitee object.
Instance Method Summary collapse
-
#fetch ⇒ Calendly::Invitee
Get Event Invitee associated with self.
Methods included from ModelUtils
#client, #id, included, #initialize, #inspect
Instance Attribute Details
#cancel_url ⇒ String
Link to cancelling the event for the invitee.
79 80 81 |
# File 'lib/calendly/models/invitee.rb', line 79 def cancel_url @cancel_url end |
#cancellation ⇒ InviteeCancellation
Returns Provides data pertaining to the cancellation of the Invitee.
94 95 96 |
# File 'lib/calendly/models/invitee.rb', line 94 def cancellation @cancellation end |
#created_at ⇒ Time
Moment when user record was first created.
87 88 89 |
# File 'lib/calendly/models/invitee.rb', line 87 def created_at @created_at end |
#email ⇒ String
The invitee’s email address.
36 37 38 |
# File 'lib/calendly/models/invitee.rb', line 36 def email @email end |
#event ⇒ Event
Reference to Event associated with this invitee.
101 102 103 |
# File 'lib/calendly/models/invitee.rb', line 101 def event @event end |
#first_name ⇒ String
The first name of the invitee who booked the event when the event type is configured to use separate fields for first name and last name. Null when event type is configured to use a single field for name.
45 46 47 |
# File 'lib/calendly/models/invitee.rb', line 45 def first_name @first_name end |
#last_name ⇒ String
The last name of the invitee who booked the event when the event type is configured to use separate fields for first name and last name. Null when event type is configured to use a single field for name.
50 51 52 |
# File 'lib/calendly/models/invitee.rb', line 50 def last_name @last_name end |
#name ⇒ String
The invitee’s human-readable name.
40 41 42 |
# File 'lib/calendly/models/invitee.rb', line 40 def name @name end |
#new_invitee ⇒ String?
Link to new invitee, after reschedule.
75 76 77 |
# File 'lib/calendly/models/invitee.rb', line 75 def new_invitee @new_invitee end |
#old_invitee ⇒ String?
Reference to old Invitee instance that got rescheduled.
71 72 73 |
# File 'lib/calendly/models/invitee.rb', line 71 def old_invitee @old_invitee end |
#payment ⇒ InviteePayment
Returns Invitee payment.
97 98 99 |
# File 'lib/calendly/models/invitee.rb', line 97 def payment @payment end |
#questions_and_answers ⇒ Array<Calendly::InviteeQuestionAndAnswer>
A collection of form responses from the invitee.
105 106 107 |
# File 'lib/calendly/models/invitee.rb', line 105 def questions_and_answers @questions_and_answers end |
#reschedule_url ⇒ String
Link to rescheduling the event for the invitee.
83 84 85 |
# File 'lib/calendly/models/invitee.rb', line 83 def reschedule_url @reschedule_url end |
#rescheduled ⇒ Boolean
Indicates if this invitee has rescheduled. If true, a reference to the new Invitee instance is provided in the new_invitee field.
67 68 69 |
# File 'lib/calendly/models/invitee.rb', line 67 def rescheduled @rescheduled end |
#status ⇒ String
Whether the invitee has canceled or is still active.
54 55 56 |
# File 'lib/calendly/models/invitee.rb', line 54 def status @status end |
#text_reminder_number ⇒ String
Text (SMS) reminder phone number.
62 63 64 |
# File 'lib/calendly/models/invitee.rb', line 62 def text_reminder_number @text_reminder_number end |
#timezone ⇒ String
Timezone offest to use when presenting time information to invitee.
58 59 60 |
# File 'lib/calendly/models/invitee.rb', line 58 def timezone @timezone end |
#tracking ⇒ Calendly::InviteeTracking
108 109 110 |
# File 'lib/calendly/models/invitee.rb', line 108 def tracking @tracking end |
#updated_at ⇒ Time
Moment when user record was last updated.
91 92 93 |
# File 'lib/calendly/models/invitee.rb', line 91 def updated_at @updated_at end |
#uri ⇒ String
Canonical resource reference.
32 33 34 |
# File 'lib/calendly/models/invitee.rb', line 32 def uri @uri end |
#uuid ⇒ String
unique id of the Invitee object.
28 29 30 |
# File 'lib/calendly/models/invitee.rb', line 28 def uuid @uuid end |
Instance Method Details
#fetch ⇒ Calendly::Invitee
Get Event Invitee associated with self.
118 119 120 121 |
# File 'lib/calendly/models/invitee.rb', line 118 def fetch ev_uuid = event.uuid if event client.event_invitee ev_uuid, uuid end |