Class: Calendly::Invitee

Inherits:
Object
  • Object
show all
Includes:
ModelUtils
Defined in:
lib/calendly/models/invitee.rb

Overview

Calendly’s Invitee model. An individual who has been invited to meet with a Calendly member.

Constant Summary collapse

UUID_RE =
%r{\A#{Client::API_HOST}/scheduled_events/\w+/invitees/(\w+)\z}.freeze
TIME_FIELDS =
i[created_at updated_at].freeze
ASSOCIATION =
{event: Event}.freeze

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from ModelUtils

#client, #id, included, #initialize, #inspect

Instance Attribute Details

#created_atTime

Moment when user record was first created.

Returns:

  • (Time)


39
40
41
# File 'lib/calendly/models/invitee.rb', line 39

def created_at
  @created_at
end

#emailString

The invitee’s email address.

Returns:

  • (String)


24
25
26
# File 'lib/calendly/models/invitee.rb', line 24

def email
  @email
end

#eventEvent

Reference to Event associated with this invitee.

Returns:



46
47
48
# File 'lib/calendly/models/invitee.rb', line 46

def event
  @event
end

#nameString

The invitee’s human-readable name.

Returns:

  • (String)


27
28
29
# File 'lib/calendly/models/invitee.rb', line 27

def name
  @name
end

#questions_and_answersArray<Calendly::InviteeQuestionAndAnswer>

A collection of form responses from the invitee.



50
51
52
# File 'lib/calendly/models/invitee.rb', line 50

def questions_and_answers
  @questions_and_answers
end

#statusString

Whether the invitee has canceled or is still active.

Returns:

  • (String)


30
31
32
# File 'lib/calendly/models/invitee.rb', line 30

def status
  @status
end

#text_reminder_numberString

Text (SMS) reminder phone number.

Returns:

  • (String)


36
37
38
# File 'lib/calendly/models/invitee.rb', line 36

def text_reminder_number
  @text_reminder_number
end

#timezoneString

Timezone offest to use when presenting time information to invitee.

Returns:

  • (String)


33
34
35
# File 'lib/calendly/models/invitee.rb', line 33

def timezone
  @timezone
end

#trackingCalendly::InviteeTracking



53
54
55
# File 'lib/calendly/models/invitee.rb', line 53

def tracking
  @tracking
end

#updated_atTime

Moment when user record was last updated.

Returns:

  • (Time)


42
43
44
# File 'lib/calendly/models/invitee.rb', line 42

def updated_at
  @updated_at
end

#uriString

Canonical resource reference.

Returns:

  • (String)


21
22
23
# File 'lib/calendly/models/invitee.rb', line 21

def uri
  @uri
end

#uuidString

unique id of the Invitee object.

Returns:

  • (String)


18
19
20
# File 'lib/calendly/models/invitee.rb', line 18

def uuid
  @uuid
end

Instance Method Details

#fetchCalendly::Invitee

Get Event Invitee associated with self.

Returns:

Raises:

Since:

  • 0.1.0



63
64
65
66
# File 'lib/calendly/models/invitee.rb', line 63

def fetch
  ev_uuid = event.uuid if event
  client.event_invitee ev_uuid, uuid
end