Class: Calendly::WebhookSubscription
- Inherits:
-
Object
- Object
- Calendly::WebhookSubscription
- Includes:
- ModelUtils
- Defined in:
- lib/calendly/models/webhook_subscription.rb
Overview
Calendly’s webhook model.
Constant Summary collapse
- UUID_RE =
%r{\A#{Client::API_HOST}/webhook_subscriptions/(#{UUID_FORMAT})\z}.freeze
- TIME_FIELDS =
i[created_at updated_at retry_started_at].freeze
- ASSOCIATION =
{organization: Organization, user: User, creator: User}.freeze
Constants included from ModelUtils
Instance Attribute Summary collapse
-
#callback_url ⇒ String
The callback URL to use when the event is triggered.
-
#created_at ⇒ Time
The moment when the webhook subscription was created.
-
#creator ⇒ Calendly::User
The user who created the webhook subscription.
-
#events ⇒ Array<String>
A list of events to which the webhook is subscribed.
-
#organization ⇒ Calendly::Organization
The organization that’s associated with the webhook subscription.
-
#retry_started_at ⇒ Time
The date and time the webhook subscription is retried.
-
#scope ⇒ String
The scope of the webhook subscription.
-
#state ⇒ String
Indicates if the webhook subscription is “active” or “disabled”.
-
#updated_at ⇒ Time
The moment when the webhook subscription was last updated.
-
#uri ⇒ String
Canonical reference (unique identifier) for the webhook.
-
#user ⇒ Calendly::User
The user that’s associated with the webhook subscription.
-
#uuid ⇒ String
unique id of the WebhookSubscription object.
Instance Method Summary collapse
-
#delete ⇒ true
Delete a webhook subscription associated with self.
-
#fetch ⇒ Calendly::WebhookSubscription
Get a webhook subscription associated with self.
Methods included from ModelUtils
#client, #id, included, #initialize, #inspect
Instance Attribute Details
#callback_url ⇒ String
The callback URL to use when the event is triggered.
26 27 28 |
# File 'lib/calendly/models/webhook_subscription.rb', line 26 def callback_url @callback_url end |
#created_at ⇒ Time
The moment when the webhook subscription was created.
30 31 32 |
# File 'lib/calendly/models/webhook_subscription.rb', line 30 def created_at @created_at end |
#creator ⇒ Calendly::User
The user who created the webhook subscription.
62 63 64 |
# File 'lib/calendly/models/webhook_subscription.rb', line 62 def creator @creator end |
#events ⇒ Array<String>
A list of events to which the webhook is subscribed.
46 47 48 |
# File 'lib/calendly/models/webhook_subscription.rb', line 46 def events @events end |
#organization ⇒ Calendly::Organization
The organization that’s associated with the webhook subscription.
54 55 56 |
# File 'lib/calendly/models/webhook_subscription.rb', line 54 def organization @organization end |
#retry_started_at ⇒ Time
The date and time the webhook subscription is retried.
38 39 40 |
# File 'lib/calendly/models/webhook_subscription.rb', line 38 def retry_started_at @retry_started_at end |
#scope ⇒ String
The scope of the webhook subscription.
50 51 52 |
# File 'lib/calendly/models/webhook_subscription.rb', line 50 def scope @scope end |
#state ⇒ String
Indicates if the webhook subscription is “active” or “disabled”.
42 43 44 |
# File 'lib/calendly/models/webhook_subscription.rb', line 42 def state @state end |
#updated_at ⇒ Time
The moment when the webhook subscription was last updated.
34 35 36 |
# File 'lib/calendly/models/webhook_subscription.rb', line 34 def updated_at @updated_at end |
#uri ⇒ String
Canonical reference (unique identifier) for the webhook.
22 23 24 |
# File 'lib/calendly/models/webhook_subscription.rb', line 22 def uri @uri end |
#user ⇒ Calendly::User
The user that’s associated with the webhook subscription.
58 59 60 |
# File 'lib/calendly/models/webhook_subscription.rb', line 58 def user @user end |
#uuid ⇒ String
unique id of the WebhookSubscription object.
18 19 20 |
# File 'lib/calendly/models/webhook_subscription.rb', line 18 def uuid @uuid end |
Instance Method Details
#delete ⇒ true
Delete a webhook subscription associated with self.
82 83 84 |
# File 'lib/calendly/models/webhook_subscription.rb', line 82 def delete client.delete_webhook uuid end |
#fetch ⇒ Calendly::WebhookSubscription
Get a webhook subscription associated with self.
71 72 73 |
# File 'lib/calendly/models/webhook_subscription.rb', line 71 def fetch client.webhook uuid end |